@@ -1,7 +1,7 @@
 /*
- *  $Id: test.cpp,v 1.10 1999/09/30 17:40:45 sbooth Exp $
+ *  $Id: test.cpp,v 1.13 2000/10/15 15:59:53 sbooth Exp $
  *
- *  Copyright (C) 1996, 1997, 1998, 1999 Stephen F. Booth
+ *  Copyright (C) 1996, 1997, 1998, 1999, 2000 Stephen F. Booth
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -40,7 +40,7 @@
 // To use logging, the variable gLogFile MUST be defined, and it _must_
 // be an ofstream
 #if DEBUG
-  STDNS ofstream gLogFile( "/change_this_path/Cgicc.log", STDNS ios::app );
+  STDNS ofstream gLogFile( "/change_this_path/cgicc.log", STDNS ios::app );
 #endif
 
 #if CGICC_USE_NAMESPACES
@@ -112,7 +112,7 @@ main(int /*argc*/,
 
     cout << comment() << style() << endl;
 
-    cout << title() << "GNU Cgicc v" << cgi.getVersion() << " Test Results" 
+    cout << title() << "GNU cgicc v" << cgi.getVersion() << " Test Results" 
 	 << title() << endl;
     cout << meta().set("name", "author").set("content", "Stephen F. Booth") 
 	 << endl;
@@ -122,16 +122,16 @@ main(int /*argc*/,
     // Start the HTML body
     cout << body() << endl;
 
-    cout << h1() << "GNU Cgi" << span("cc").set("class","red")
+    cout << h1() << "GNU cgi" << span("cc").set("class","red")
 	 << " v"<< cgi.getVersion() << " Test Results" << h1() << endl;
     
     // Get a pointer to the environment
     const CgiEnvironment& env = cgi.getEnvironment();
     
     // Generic thank you message
-    cout << comment() << "This page generated by Cgicc for "
+    cout << comment() << "This page generated by cgicc for "
 	 << env.getRemoteHost() << comment() << endl;
-    cout << h4() << "Thanks for using Cgi" << span("cc").set("class", "red") 
+    cout << h4() << "Thanks for using cgi" << span("cc").set("class", "red") 
 	 << ", " << env.getRemoteHost() 
 	 << '(' << env.getRemoteAddr() << ")!" << h4() << endl;  
     
@@ -188,12 +188,12 @@ main(int /*argc*/,
 	 << endl;
     cout << CGICCNS div() << br() << hr(set("class","half")) << endl;
     
-    // Information on Cgicc
+    // Information on cgicc
     cout << CGICCNS div().set("align","center").set("class","smaller") << endl;
-    cout << "GNU Cgi" << span("cc").set("class","red") << " v";
+    cout << "GNU cgi" << span("cc").set("class","red") << " v";
     cout << cgi.getVersion();
     cout << " by " << a("Stephen F. Booth")
-                       .set("href", "http://www.lmi.net/~sbooth/") 
+                       .set("href", "http://home.earthlink.net/~sfbooth/") 
 	 << br() << endl;
     cout << "Compiled at " << cgi.getCompileTime();
     cout << " on " << cgi.getCompileDate() << br() << endl;
@@ -261,7 +261,7 @@ main(int /*argc*/,
 
     cout << comment() << style() << endl;
 
-    cout << title("GNU Cgicc exception") << endl;
+    cout << title("GNU cgicc exception") << endl;
     cout << meta().set("name", "author")
 		  .set("content", "Stephen F. Booth") << endl;
     cout << head() << endl;
